/*
 * geoclue.h: Geoclue convenience library.
 *
 * Copyright 2010-2011,2015 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
 */

#ifndef __GEOCLUE_H__
#define __GEOCLUE_H__

#include <glib-object.h>
#include <gio/gio.h>

#include <gclue-enums.h>
#include <gclue-enum-types.h>
#include <gclue-client.h>
#include <gclue-location.h>
#include <gclue-manager.h>
#include <gclue-helpers.h>
#include <gclue-simple.h>

#endif /* __GEOCLUE_H__ */
